#
# spec file for package python-ipyscales
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mainver 0.7.0
%define shortmainver 0.7
%define labver  3.3.0

Name:           python-ipyscales
Version:        %{mainver}
Release:        6.2
Summary:        A widget library for scales
License:        BSD-3-Clause
URL:            https://github.com/vidartf/ipyscales
Source0:        https://files.pythonhosted.org/packages/py2.py3/i/ipyscales/ipyscales-%{mainver}-py2.py3-none-any.whl
BuildRequires:  %{python_module base >= 3.5}
BuildRequires:  %{python_module pip}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
Requires:       jupyter-ipyscales = %{version}
Requires:       python-ipywidgets >= 7.0.0
Recommends:     python-ipydatawidgets
Provides:       python-jupyter_ipyscales = %{version}-%{release}
Obsoletes:      python-jupyter_ipyscales < %{version}-%{release}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module ipywidgets >= 7.6}
BuildRequires:  %{python_module ipydatawidgets >= 4.2}
BuildRequires:  %{python_module nbval}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A Jupyter/IPython widget library for scales.

This package provides the python interface.

%package     -n jupyter-ipyscales
Summary:        A Jupyter widget library for scales
Requires:       ((jupyter-notebook >= 4.0.0 with jupyter-notebook < 7) or jupyter-nbclassic)
Conflicts:      python3-jupyter_ipyscales < 0.4.0
Requires:       python3dist(ipyscales) = %{shortmainver}
Suggests:       python3-ipyscales

%description -n jupyter-ipyscales
A Jupyter/IPython widget library for scales.

This package provides the jupyter notebook extension.

%package     -n jupyter-jupyterlab-ipyscales
Version:        %{labver}
Summary:        A JupyterLab widget library for scales
Requires:       jupyter-jupyterlab
Requires:       python3dist(ipyscales) = %{shortmainver}
Suggests:       python3-ipyscales

%description -n jupyter-jupyterlab-ipyscales
A Jupyter/IPython widget library for scales.

This package provides the Jupyterlab widget

After installation you must run:
jupyter labextension install @jupyter-widgets/jupyterlab-manager

%prep
%setup -q -c -T

%build
# must use upstream wheel: npm build requires online connection
:

%install
%pyproject_install %{SOURCE0}
builddir=${PWD}
%{python_expand # must patch everything after installing from wheel
pushd %{buildroot}%{$python_sitelib}
cp ipyscales-%{mainver}.dist-info/LICENSE.txt ${builddir}
find ipyscales -name '*.py' \
  -exec dos2unix '{}' ';' \
  -exec sed -i '1{/env python/ d}' '{}' ';'
# gh#vidartf/ipyscales#29
sed -i 's/np.float/float/' ipyscales/tests/test_colorarray.py
popd
}
%python_compileall
%jupyter_move_config
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_jupyter_prefix}

%check
%pytest --pyargs ipyscales

%files %{python_files}
%license LICENSE.txt
%{python_sitelib}/ipyscales
%{python_sitelib}/ipyscales-%{mainver}.dist-info/

%files -n jupyter-ipyscales
%license LICENSE.txt
%{_jupyter_nbextension_dir}/jupyter-scales/
%_jupyter_config %{_jupyter_nb_notebook_confdir}/jupyter-scales.json

%files -n jupyter-jupyterlab-ipyscales
%license LICENSE.txt
%{_jupyter_labextensions_dir}/jupyter-scales-%{labver}.tgz
%{_jupyter_labextensions_dir3}/jupyter-scales

%changelog
* Sat Aug 26 2023 Ben Greiner <code@bnavigator.de>
- Avoid notebook 7: use nbclassic or notebook 6 for extension
* Sat Aug 26 2023 Ben Greiner <code@bnavigator.de>
- Refine jupyter requirement and recommendation chain
* Sun Jan  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.7.0 with jupyter-scale 3.3.0
  * no release notes
- Fix gh#vidartf/ipyscales#29
- Cleanup jupyter-* packages
* Wed May 11 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.6.0 with jupyter-scales 3.2.0
  * no release notes
- fix fdupes errors
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Fri Aug 16 2019 Todd R <toddrme2178@gmail.com>
- The full jupyterlab isn't needed for install
* Wed May 15 2019 Todd R <toddrme2178@gmail.com>
- Fixed typo
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.4.0
  * Regenerate examples with new frontend version
  * Tweak RTD env
  * Update chromabar/d3 deps
  * Fix change notification for value's scale
  * Scaled value initial implementation
  * Ensure we update listens on scale for data
  * Add ArrayColorScale
  * Add color map notebook
  * Add ordinal color maps
  * Add scaled data example (also add to docs)
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.3.0
  * Clean up dist config
  * Check in package lock
  * Do not include coverage in JS package
  * Fix docs requirements
  * Fix syncToModel
  * Rename widgets (remove Widget postfix)
  * Add log scale
  * Add more advanced color trait
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 0.2.2
  * Fix nbextension dist again
  * Fix datafiles spec
  * Sync npm deps
  * Cleanup setup and distribution
  * Add dash to lab package keyword
* Tue May 29 2018 toddrme2178@gmail.com
- Use || true syntax instead of exit 0
* Sun Apr 22 2018 toddrme2178@gmail.com
- Initial version
